summaryrefslogtreecommitdiff
path: root/TAO/tao/TAO_Singleton.h
diff options
context:
space:
mode:
authorOssama Othman <ossama-othman@users.noreply.github.com>2002-03-08 04:46:32 +0000
committerOssama Othman <ossama-othman@users.noreply.github.com>2002-03-08 04:46:32 +0000
commitbfe7a238f371328682ab9ba84276067086d8aa44 (patch)
tree23cb4397202bf6f95733da17ca3115cbc0bfd1c3 /TAO/tao/TAO_Singleton.h
parent0ba131ad7aabf15f7342cea8be4e00c52c2f5c63 (diff)
downloadATCD-bfe7a238f371328682ab9ba84276067086d8aa44.tar.gz
ChangeLogTag:Thu Mar 7 20:43:56 2002 Ossama Othman <ossama@uci.edu>
Diffstat (limited to 'TAO/tao/TAO_Singleton.h')
-rw-r--r--TAO/tao/TAO_Singleton.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/TAO/tao/TAO_Singleton.h b/TAO/tao/TAO_Singleton.h
index 1bfc9091c7b..3069d80edb6 100644
--- a/TAO/tao/TAO_Singleton.h
+++ b/TAO/tao/TAO_Singleton.h
@@ -7,8 +7,7 @@
* $Id$
*
* Header file for the TAO-specific Singleton implementation.
* Based entirely on tao/TAO_Singleton.*.
*
*
* @author Ossama Othman <ossama@uci.edu>
*/
@@ -109,6 +108,12 @@ protected:
/// Get pointer to the TAO TSS Singleton instance.
static TAO_TSS_Singleton<TYPE, ACE_LOCK> *&instance_i (void);
+
+private:
+
+ ACE_UNIMPLEMENTED_FUNC (void operator= (const TAO_TSS_Singleton<TYPE,ACE_LOCK> &))
+ ACE_UNIMPLEMENTED_FUNC (TAO_TSS_Singleton (const TAO_TSS_Singleton<TYPE,ACE_LOCK> &))
+
};
#if defined (__ACE_INLINE__)
@@ -7,8 +7,7 @@
*
* Header file for the TAO-specific Singleton implementation.
- * Based entirely on tao/TAO_Singleton.*.
- *
+ * Based entirely on ace/Singleton.*.
*
* @author Ossama Othman <ossama@uci.edu>